MethodChannelWhatsappSharePlus class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isWhatsappBusinessInstalled() Future<bool>
override
isWhatsappInstalled() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareImageToWhatsapp({required String imagePath, String? text, String? phone}) Future<bool?>
override
shareImageToWhatsappBusiness({required String imagePath, String? text, String? phone}) Future<bool?>
override
shareToWhatsapp({required String text, String? phone}) Future<bool?>
override
shareToWhatsappBusiness({required String text, String? phone}) Future<bool?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited