whatsapp_share_plus_web library
The web implementation of whatsapp_share_plus.
Registered automatically by the Flutter web plugin registrant; there is no reason to import this library directly.
Classes
- Shares to WhatsApp from a browser.
The web implementation of whatsapp_share_plus.
Registered automatically by the Flutter web plugin registrant; there is no reason to import this library directly.